@@ -74,7 +74,7 @@ rb_kz_dl_get_total_progress(VALUE self)
 
 
 void
-Init_kz_rb_downloader(VALUE mKz)
+_kz_rb_downloader_init(VALUE mKz)
 {
     VALUE cKzDownloader;
 
