@@ -318,7 +318,7 @@ kz_actions_dynamic_append_open_smart_bookmark_menuitem (KzWindow *kz,
 	GList *children, *node;
 	GtkWidget *smart_bookmark_submenu = NULL;
 	const gchar *title;
-	KzBookmark *bookmark = kz_bookmarks->smarts;
+	KzBookmark *bookmark = KZ_GET_SMART_BOOKMARK;
 	KzBookmark *child, *smart;
 
 	smart_bookmark_submenu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(menu));
