@@ -108,7 +108,7 @@ open_location (GtkAction *action, KzWindow *kz, LocationType location, WindowTyp
 		break;
 	case NEW_WINDOW:
 	{
-		GtkWidget *widget = kz_app_create_new_window(kz_app, uri);
+		GtkWidget *widget = KZ_CREATE_NEW_WINDOW(uri);
 		gtk_widget_show(widget);
 		break;
 	}
