@@ -25,6 +25,7 @@
 #include "gtk-utils.h"
 #include "kazehakase.h"
 #include "kz-icons.h"
+#include "kz-notebook.h"
 #include "kz-actions-dynamic.h"
 
 static GQuark kztab_quark = 0;
@@ -100,64 +101,46 @@ enum {
 };
 
 static void
-close_all_tab (GtkAction *action, KzWindow *kz, gint mode)
+close_tabs (KzWindow *kz, KzNotebookCloseCondition condition)
 {
 	KzTabLabel *kztab;
-	GtkNotebook *notebook;
-	gint num, pos;
-	gint i;
-
-	if(mode == KZ_TAB_CLOSE_ALL_TABS)
-	{
-		kz_window_close_all_tab(kz);
-		return;
-	}
+	KzNotebook *notebook;
+	gint pos;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
-	notebook = GTK_NOTEBOOK(kztab->kz->notebook);
+	notebook = KZ_NOTEBOOK(kztab->kz->notebook);
 
-	num = gtk_notebook_get_n_pages(notebook);
-	pos = gtk_notebook_page_num(notebook, GTK_WIDGET(kztab->kzembed));
+	pos = kz_notebook_page_num(notebook, GTK_WIDGET(kztab->kzembed));
 
-	if (num < 2 || pos < 0) return;
-
-	for (i = num - 1; i >= 0; i--)
-	{
-		GtkWidget *widget = KZ_WINDOW_NTH_PAGE(kztab->kz, i);
-
-		if (i == pos) continue;
-		if (i > pos && mode == KZ_TAB_CLOSE_BACKWARD) continue;
-		if (i < pos && mode == KZ_TAB_CLOSE_FORWARD) continue;
-
-		kz_window_close_tab(kztab->kz, widget);
-	}
+	kz_notebook_close_tabs(notebook, condition, pos);
 }
 
 static void
 act_tab_close_left (GtkAction *action, KzWindow *kz)
 {
-	close_all_tab(action, kz, KZ_TAB_CLOSE_BACKWARD);
+	close_tabs(kz, KZ_NOTEBOOK_CLOSE_BACKWARD);
 }
 
 static void
 act_tab_close_right (GtkAction *action, KzWindow *kz)
 {
-	close_all_tab(action, kz, KZ_TAB_CLOSE_FORWARD);
+	close_tabs(kz, KZ_NOTEBOOK_CLOSE_FORWARD);
 }
 
 static void
-act_tab_close_all_inactive_active (GtkAction *action, KzWindow *kz)
+act_tab_close_all_inactive (GtkAction *action, KzWindow *kz)
 {
-	close_all_tab(action, kz, KZ_TAB_CLOSE_INACTIVE);
+	close_tabs(kz, KZ_NOTEBOOK_CLOSE_INACTIVE);
 }
 
 static void
 act_tab_close_all_tabs (GtkAction *action, KzWindow *kz)
 {
-	close_all_tab(action, kz, KZ_TAB_CLOSE_ALL_TABS);
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+	kz_window_close_all_tab(kz);
 }
 
 static gboolean
@@ -204,7 +187,7 @@ static void
 act_tab_close_all_same_site (GtkAction *action, KzWindow *kz)
 {
 	KzTabLabel *kztab;
-	GtkNotebook *notebook;
+	KzNotebook *notebook;
 	gint num;
 	gint i;
 	gchar **src;
@@ -215,8 +198,8 @@ act_tab_close_all_same_site (GtkAction *action, KzWindow *kz)
 	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
 
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
-	notebook = GTK_NOTEBOOK(kztab->kz->notebook);
-	num = gtk_notebook_get_n_pages(notebook);
+	notebook = KZ_NOTEBOOK(kztab->kz->notebook);
+	num = kz_notebook_get_n_pages(notebook);
 	if (num < 2) return;
 
 	src = g_strsplit(kz_embed_get_location(KZ_EMBED(kztab->kzembed)),
@@ -393,7 +376,7 @@ GtkActionEntry kz_actions_tab[] =
 	 NULL, NULL, G_CALLBACK(act_tab_close_right)},
 
 	{"TabCloseAllInactiveTabs", GTK_STOCK_CLOSE, N_("Close all _inactive tabs"),
-	 NULL, NULL, G_CALLBACK(act_tab_close_all_inactive_active)},
+	 NULL, NULL, G_CALLBACK(act_tab_close_all_inactive)},
 
 	{"TabCloseAllTabs", GTK_STOCK_CLOSE, N_("Clos_e all tabs"),
 	 NULL, NULL, G_CALLBACK(act_tab_close_all_tabs)},
@@ -476,9 +459,9 @@ set_popup_menu_sensitive (KzTabLabel *kztab)
 	kz = kztab->kz;
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	pos = gtk_notebook_page_num(GTK_NOTEBOOK(kztab->kz->notebook),
-				    GTK_WIDGET(kztab->kzembed));
-	num = gtk_notebook_get_n_pages(GTK_NOTEBOOK(kztab->kz->notebook));
+	pos = kz_notebook_page_num(KZ_NOTEBOOK(kztab->kz->notebook),
+				   GTK_WIDGET(kztab->kzembed));
+	num = kz_notebook_get_n_pages(KZ_NOTEBOOK(kztab->kz->notebook));
 
 	action = gtk_action_group_get_action(kz->tabpop_actions, "TabStop");
 	g_object_set(action, "sensitive", 
