@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.68 2006/01/06 02:58:42 makeinu Exp $
+ *  $Id: kz-xbel.c 3100 2007-03-30 00:14:13Z kous $
  */
 
 #include "kazehakase.h"
@@ -47,15 +47,20 @@ static void     kz_xbel_insert_xml_node    (KzBookmark  *bookmark,
 					    KzBookmark  *parent,
 					    KzBookmark  *sibling);
 static void     kz_xbel_remove_xml_node    (KzBookmark  *bookmark);
-static void     kz_xbel_connect_signals    (KzBookmark  *bookmark);
-static void     kz_xbel_disconnect_signals (KzBookmark  *bookmark);
+static void     kz_xbel_connect_signals    (KzBookmark  *bookmark,
+					    gpointer     data);
+static void     kz_xbel_disconnect_signals (KzBookmark  *bookmark,
+					    gpointer     data);
 static void     cb_bookmark_insert_child   (KzBookmark  *bookmark,
 					    KzBookmark  *child,
-					    KzBookmark  *sibling);
+					    KzBookmark  *sibling,
+					    gpointer     data);
 static void     cb_bookmark_remove_child   (KzBookmark  *bookmark,
-					    KzBookmark  *child);
+					    KzBookmark  *child,
+					    gpointer     data);
 static void     cb_bookmark_notify         (GObject     *object,
-					    GParamSpec  *spec);
+					    GParamSpec  *spec,
+					    gpointer     data);
 
 static void     xml_node_set_title         (KzXMLNode   *parent,
 					    const gchar *title);
@@ -77,12 +82,12 @@ static GQuark building_quark = 0;
 
 static KzBookmarkFileType xbel_file_type =
 {
-	priority_hint: 0,
-	file_type:     "XBEL",
-	init:          kz_xbel_init,
-	is_supported:  kz_xbel_is_supported,
-	from_string:   kz_xbel_from_string,
-	to_string:     kz_xbel_to_string,
+	/* .priority_hint = */ 0,
+	/* .file_type     = */ "XBEL",
+	/* .init          = */ kz_xbel_init,
+	/* .is_supported  = */ kz_xbel_is_supported,
+	/* .from_string   = */ kz_xbel_from_string,
+	/* .to_string     = */ kz_xbel_to_string,
 };
 
 
@@ -144,9 +149,9 @@ kz_xbel_init (KzBookmarkFile *bookmark)
 	g_signal_connect(bookmark, "notify",
 			 G_CALLBACK(kz_xbel_notify), xml);
 	g_signal_connect_after(bookmark, "insert-child",
-			       G_CALLBACK(cb_bookmark_insert_child), xml);
+			       G_CALLBACK(cb_bookmark_insert_child), bookmark);
 	g_signal_connect_after(bookmark, "remove-child",
-			       G_CALLBACK(cb_bookmark_remove_child), xml);
+			       G_CALLBACK(cb_bookmark_remove_child), bookmark);
 }
 
 
@@ -259,6 +264,9 @@ kz_xbel_notify (GObject *object, GParamSpec *pspec, KzXML *xml)
 		g_free(title);
 	}
 	g_value_unset(&value);
+
+	/* emit update signal */
+	g_signal_emit_by_name(object, "update", 0);
 }
 
 
@@ -577,7 +585,6 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 
 			if (xml_node_has_location(node))
 			{
-#warning FIXME! If the file does not exit, we should creat it.
 				const gchar *location = xml_node_get_location(node);
 
 				folder = KZ_BOOKMARK(kz_bookmark_file_new(location,
@@ -1161,20 +1168,20 @@ create_xml_node (KzBookmark *bookmark)
 
 
 static void
-kz_xbel_connect_signals (KzBookmark *bookmark)
+kz_xbel_connect_signals (KzBookmark *bookmark, gpointer data)
 {
 	g_signal_connect(bookmark, "notify",
-			 G_CALLBACK(cb_bookmark_notify), NULL);
+			 G_CALLBACK(cb_bookmark_notify), data);
 
 	if (KZ_IS_BOOKMARK_FILE(bookmark)) return;
 	if (!kz_bookmark_is_folder(bookmark)) return;
 
 	g_signal_connect_after(bookmark, "insert-child",
 			       G_CALLBACK(cb_bookmark_insert_child),
-			       NULL);
+			       data);
 	g_signal_connect_after(bookmark, "remove-child",
 			       G_CALLBACK(cb_bookmark_remove_child),
-			       NULL);
+			       data);
 
 	/* for children */
 	{
@@ -1184,7 +1191,7 @@ kz_xbel_connect_signals (KzBookmark *bookmark)
 		for (node = children; node; node = g_list_next(node))
 		{
 			KzBookmark *child = node->data;
-			kz_xbel_connect_signals(child);
+			kz_xbel_connect_signals(child, data);
 		}
 		g_list_free(children);
 	}
@@ -1192,21 +1199,21 @@ kz_xbel_connect_signals (KzBookmark *bookmark)
 
 
 static void
-kz_xbel_disconnect_signals (KzBookmark *bookmark)
+kz_xbel_disconnect_signals (KzBookmark *bookmark, gpointer data)
 {
 	g_signal_handlers_disconnect_by_func
 		(bookmark,
-		 G_CALLBACK(cb_bookmark_notify), NULL);
+		 G_CALLBACK(cb_bookmark_notify), data);
 
 	if (KZ_IS_BOOKMARK_FILE(bookmark)) return;
 	if (!kz_bookmark_is_folder(bookmark)) return;
 
 	g_signal_handlers_disconnect_by_func
 		(bookmark,
-		 G_CALLBACK(cb_bookmark_insert_child), NULL);
+		 G_CALLBACK(cb_bookmark_insert_child), data);
 	g_signal_handlers_disconnect_by_func
 		(bookmark,
-		 G_CALLBACK(cb_bookmark_remove_child), NULL);
+		 G_CALLBACK(cb_bookmark_remove_child), data);
 
 	/* for children */
 	{
@@ -1216,7 +1223,7 @@ kz_xbel_disconnect_signals (KzBookmark *bookmark)
 		for (node = children; node; node = g_list_next(node))
 		{
 			KzBookmark *child = node->data;
-			kz_xbel_disconnect_signals(child);
+			kz_xbel_disconnect_signals(child, data);
 		}
 		g_list_free(children);
 	}
@@ -1225,18 +1232,23 @@ kz_xbel_disconnect_signals (KzBookmark *bookmark)
 
 static void
 cb_bookmark_insert_child (KzBookmark *bookmark,
-			  KzBookmark *child, KzBookmark *sibling)
+			  KzBookmark *child, KzBookmark *sibling,
+			  gpointer data)
 {
 	kz_xbel_insert_xml_node(child, bookmark, sibling);
-	kz_xbel_connect_signals(child);
+	kz_xbel_connect_signals(child, data);
+
+	g_signal_emit_by_name(G_OBJECT(data), "update", 0);
 }
 
 
 static void
-cb_bookmark_remove_child (KzBookmark *bookmark, KzBookmark *child)
+cb_bookmark_remove_child (KzBookmark *bookmark, KzBookmark *child, gpointer data)
 {
-	kz_xbel_disconnect_signals(child);
+	kz_xbel_disconnect_signals(child, data);
 	kz_xbel_remove_xml_node(child);
+
+	g_signal_emit_by_name(G_OBJECT(data), "update", 0);
 }
 
 
@@ -1328,7 +1340,7 @@ xml_node_set_description (KzXMLNode *parent, const gchar *desc)
 
 
 static void
-cb_bookmark_notify (GObject *object, GParamSpec *pspec)
+cb_bookmark_notify (GObject *object, GParamSpec *pspec, gpointer data)
 {
 	KzBookmark *bookmark;
 	KzXMLNode *node;
@@ -1520,6 +1532,7 @@ cb_bookmark_notify (GObject *object, GParamSpec *pspec)
 		kz_xml_node_set_attr(metanode, "kz:javascript", str);
 	}
 	g_value_unset(&value);
+	g_signal_emit_by_name(G_OBJECT(data), "update", 0);
 }
 
 
@@ -1567,6 +1580,11 @@ kz_xbel_insert_xml_node (KzBookmark *bookmark,
 		g_return_if_fail(KZ_IS_XML(xml));
 
 		parent_node = kz_xml_get_root_element(xml);
+		if (!parent_node)
+		{
+			parent_node = kz_xml_element_node_new("xbel");
+			kz_xml_set_root_element(xml, parent_node);
+		}
 		g_return_if_fail (kz_xml_node_name_is(parent_node, "xbel"));
 	}
 
