@@ -23,7 +23,6 @@
 
 #include "kz-download-box.h"
 #include "kz-actions-download.h"
-#include "gobject-utils.h"
 #include "gtk-utils.h"
 
 enum {
@@ -31,25 +30,23 @@ enum {
 	PROP_KZ_WINDOW
 };
 
-static void kz_download_box_class_init   (KzDownloadBoxClass *klass);
-static void kz_download_box_init         (KzDownloadBox      *dlbox);
-static void kz_download_box_dispose      (GObject            *object);
-static void kz_download_box_set_property (GObject            *object,
-					  guint               prop_id,
-					  const GValue       *value,
-					  GParamSpec         *pspec);
-static void kz_download_box_get_property (GObject            *object,
-					  guint               prop_id,
-					  GValue             *value,
-					  GParamSpec         *pspec);
+static void dispose      (GObject            *object);
+static void set_property (GObject            *object,
+	        	  guint               prop_id,
+	        	  const GValue       *value,
+	        	  GParamSpec         *pspec);
+static void get_property (GObject            *object,
+	        	  guint               prop_id,
+	        	  GValue             *value,
+	        	  GParamSpec         *pspec);
 
-static void kz_download_box_drag_data_received (GtkWidget        *widget,
-						GdkDragContext   *context,
-						gint              x,
-						gint              y,
-						GtkSelectionData *data,
-						guint             info,
-						guint             time);
+static void drag_data_received (GtkWidget        *widget,
+                                GdkDragContext   *context,
+                                gint              x,
+                                gint              y,
+                                GtkSelectionData *data,
+                                guint             info,
+                                guint             time);
 
 static void cb_add_item       (KzDownloaderGroup *dlgrp,
 			       KzDownloader      *dl,
@@ -63,8 +60,6 @@ static void cb_progress_item  (KzDownloaderGroup *dlgrp,
 
 static void remove_icon       (KzDownloaderIcon *icon);
 
-static GtkStatusbarClass *parent_class = NULL;
-
 enum {
 	TARGET_NETSCAPE_URL,
 	TARGET_TEXT_URI_LIST
@@ -78,9 +73,7 @@ static GtkTargetEntry url_drag_types [] =
 
 static guint n_url_drag_types = G_N_ELEMENTS (url_drag_types);
 
-KZ_OBJECT_GET_TYPE(kz_download_box, "KzDownloadBox", KzDownloadBox,
-		   kz_download_box_class_init, kz_download_box_init,
-		   GTK_TYPE_STATUSBAR)
+G_DEFINE_TYPE(KzDownloadBox, kz_download_box, GTK_TYPE_STATUSBAR)
 
 static void
 kz_download_box_class_init (KzDownloadBoxClass *klass)
@@ -88,20 +81,20 @@ kz_download_box_class_init (KzDownloadBoxClass *klass)
 	GObjectClass *gobject_class;
 	GtkWidgetClass *widget_class;
 
-	parent_class = g_type_class_peek_parent (klass);
+	kz_download_box_parent_class = g_type_class_peek_parent (klass);
 
 	gobject_class = (GObjectClass *) klass;
 	widget_class  = (GtkWidgetClass *) klass;
 
 	/* GObject signals */
-	gobject_class->dispose      = kz_download_box_dispose;
-	gobject_class->set_property = kz_download_box_set_property;
-	gobject_class->get_property = kz_download_box_get_property;
+	gobject_class->dispose      = dispose;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	/* GtkWidget signales */
 	/* widget_class->drag_motion          = kz_download_box_drag_motion; */
 	/* widget_class->drag_data_get        = kz_download_box_drag_data_get; */
-	widget_class->drag_data_received   = kz_download_box_drag_data_received;
+	widget_class->drag_data_received   = drag_data_received;
 	
 	g_object_class_install_property
 		(gobject_class,
@@ -140,10 +133,10 @@ kz_download_box_init (KzDownloadBox *dlbox)
 
 
 static void
-kz_download_box_set_property (GObject            *object,
-			      guint               prop_id,
-			      const GValue       *value,
-			      GParamSpec         *pspec)
+set_property (GObject            *object,
+              guint               prop_id,
+              const GValue       *value,
+              GParamSpec         *pspec)
 {
 	KzDownloadBox *dlbox = KZ_DOWNLOAD_BOX(object);
   
@@ -159,10 +152,10 @@ kz_download_box_set_property (GObject            *object,
 }
 
 static void
-kz_download_box_get_property (GObject            *object,
-			      guint               prop_id,
-			      GValue             *value,
-			      GParamSpec         *pspec)
+get_property (GObject            *object,
+              guint               prop_id,
+              GValue             *value,
+              GParamSpec         *pspec)
 {
 	KzDownloadBox *dlbox = KZ_DOWNLOAD_BOX(object);
 
@@ -191,7 +184,7 @@ kz_download_box_new (KzWindow *kz)
 
 
 static void
-kz_download_box_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzDownloadBox *dlbox = KZ_DOWNLOAD_BOX(object);
 
@@ -222,18 +215,18 @@ kz_download_box_dispose (GObject *object)
 		dlbox->dlgrp = NULL;
 	}
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		(*G_OBJECT_CLASS (parent_class)->dispose) (object);
+	if (G_OBJECT_CLASS (kz_download_box_parent_class)->dispose)
+		(*G_OBJECT_CLASS (kz_download_box_parent_class)->dispose) (object);
 }
 
 
 static void
-kz_download_box_drag_data_received (GtkWidget *widget,
-				    GdkDragContext *context,
-				    gint x, gint y,
-				    GtkSelectionData *data,
-				    guint info,
-				    guint time)
+drag_data_received (GtkWidget *widget,
+                    GdkDragContext *context,
+                    gint x, gint y,
+                    GtkSelectionData *data,
+                    guint info,
+                    guint time)
 {
 	KzDownloadBox *dlbox;
 	gchar **strings, *basename;
