@@ -77,21 +77,23 @@ _kz_ext_new (KzModule *module, const gchar *first_property, ...)
 void
 kz_ext_init (gpointer initial_address)
 {
-    GList *node;
-    const gchar *base_dir;
-    base_dir = g_getenv("KZ_EXT_DIR");
-    if (!base_dir)
-        base_dir = KZ_EXTDIR;
+	GList *node;
+	const gchar *base_dir;
+	base_dir = g_getenv("KZ_EXT_DIR");
+	if (!base_dir)
+		base_dir = KZ_GET_SYSTEM_EXT_DIR;
 
-    ext_mods = kz_module_load_modules(base_dir);
-    for (node = ext_mods; node; node = g_list_next(node))
-    {
-        KzExt *ext;
-        KzModule *module = node->data;
+	ext_mods = kz_module_load_modules(base_dir);
+	for (node = ext_mods; node; node = g_list_next(node))
+	{
+		KzExt *ext;
+		KzModule *module = node->data;
 
-        ext = _kz_ext_new(module, "initial-address", initial_address, NULL);
-        exts = g_list_prepend(exts, ext);
-    }
+		ext = _kz_ext_new(module,
+				  "initial-address", initial_address,
+				  NULL);
+		exts = g_list_prepend(exts, ext);
+	}
 }
 
 static void
