@@ -1031,7 +1031,7 @@ kz_http_read_from_io (KzIO *io, GIOChannel *iochannel)
 }
 
 
-static void 
+static void
 cb_http_connect(GTcpSocket *socket,
 		GTcpSocketConnectAsyncStatus status, gpointer data)
 {
@@ -1041,7 +1041,7 @@ cb_http_connect(GTcpSocket *socket,
 	gchar *command, *tmp_ua;
 	const gchar *method = methods[0];
 	gsize n;
-	gchar *URL, *host_header, *user_agent = NULL;
+	gchar *URL, *host_header = NULL, *user_agent = NULL;
 	gboolean override = FALSE;
 	KzHTTPPrivate *priv = KZ_HTTP_GET_PRIVATE (data);
 
@@ -1089,20 +1089,22 @@ cb_http_connect(GTcpSocket *socket,
 
 #ifdef USE_SSL
 	if (priv->kz_ssl)
-	{
 		host_header = g_strdup_printf("Host: %s\r\n",
 					      priv->hostname);
-	}
-	else
-	{
-		host_header = g_strdup_printf("Host: %s:%u\r\n",
-					      priv->hostname, priv->port);
-	}
-#else
-	host_header = g_strdup_printf("Host: %s:%u\r\n",
-				      priv->hostname, priv->port);
 #endif
 
+	if (!host_header)
+	{
+		if (priv->port == 80)
+			host_header = g_strdup_printf("Host: %s\r\n",
+						      priv->hostname);
+		else
+			host_header = g_strdup_printf("Host: %s:%u\r\n",
+						      priv->hostname,
+						      priv->port);
+	}
+
+
 	KZ_CONF_GET("Global", "override_user_agent", override, BOOL);
 	if (override)
 		user_agent = KZ_CONF_GET_STR("Global", "user_agent");
