@@ -38,7 +38,6 @@ G_BEGIN_DECLS
 
 typedef struct _KzHTTP KzHTTP;
 typedef struct _KzHTTPClass KzHTTPClass;
-typedef struct _KzHTTPPrivate KzHTTPPrivate;
 
 typedef enum {
 	KZ_HTTP_METHOD_GET,
@@ -50,8 +49,6 @@ typedef enum {
 struct _KzHTTP
 {
 	KzIO parent;
-	
-	KzHTTPPrivate *priv;
 };
 
 struct _KzHTTPClass
