@@ -32,11 +32,11 @@ static void           prefs_external_program_response    (GtkWidget *widget,
 
 static KzPrefsWinPageEntry prefs_entry =
 {
-	path:            N_("/External Program"),
-	priority_hint:   0,
-	ui_level:        KZ_UI_LEVEL_EXPERT,
-	create:          prefs_external_program_create,
-	response:        prefs_external_program_response,
+	/* .path          = */ N_("/External Program"),
+	/* .priority_hint = */ 0,
+	/* .ui_level      = */ KZ_UI_LEVEL_EXPERT,
+	/* .create        = */ prefs_external_program_create,
+	/* .response      = */ prefs_external_program_response,
 };
 
 typedef struct _KzPrefsExternalProgram
